/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.generator;

import org.enhydra.zeus.Binding;
import org.enhydra.zeus.ZeusException;

/**
 * <p>
 *  <code>UnsupportedBindingTypeException</code> is an extension of 
 *    <code>{@link ZeusException}</code> that provides information
 *    about a binding type that is provided for generation, but is unsupported
 *    in the referenced generation process (generally to a
 *    <code>{@link org.enhydra.zeus.Generator}</code>.
 * </p>
 * 
 * @author Brett McLaughlin
 */
public class UnsupportedBindingTypeException extends ZeusException {
    
    /**
     * <p>
     *  This indicates that an invalid <code>{@link Binding}</code> was 
     *    specified to a <code>{@link org.enhydra.zeus.Generator}</code>.
     * </p>
     */    
    public UnsupportedBindingTypeException()  {
        super("An unsupported binding type was supplied to a Generator.");
    }
    
    /**
     * <p>
     *  This indicates that an invalid <code>{@link Binding}</code> was 
     *    specified to a <code>{@link org.enhydra.zeus.Generator}</code>.
     * </p>
     *
     * @param binding the <code>Binding</code> that is unsupported.
     */    
    public UnsupportedBindingTypeException(Binding binding)  {
        super("An unsupported binding, named '" + binding.getXMLName() + 
            "', of type '" + binding.getClass().getName() +
            " was supplied to a Generator.");
    }
}
