/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

// JUnit imports
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  This is a test case for the <code>{@link SchemaUtils}</code> class.
 * </p>
 *
 * @author Brett McLaughlin
 */
public class XMLNameTest extends TestCase {

    /**
     * <p>
     *  This constructs a new <code>XMLNameTest</code>.
     * </p>
     *
     * @param name the name of the test case.
     */
    public XMLNameTest(String name) {
        super(name);
    }

    /**
     * <p>
     *  This method maeks it easier to call these
     *    tests dynamically.
     * </p>
     *
     * @return <code>TestSuite</code> - corresponds to this 
     *         <code>TestCase</code>.
     */
    public static Test suite(){
        return new TestSuite(XMLNameTest.class);
    }
    
    /**
     * <p>
     *  This creates a new <code>{@link XMLName}</code> object for testing.
     * </p>
     *
     * @return <code>XMLName</code> - the created <code>XMLName</code> object.
     */
    protected XMLName getXMLName() {
        return new XMLName("dummyName", "dummyURI");
    }

    /**
     * <p>
     *  This tests the <code>{@link XMLName#getXMLName}</code> method.
     * </p>
     */
    public void testGetXMLName() {
        XMLName xmlName = getXMLName();
        String name = "xmlName";
        xmlName.setXMLName(name);
        assertEquals(name, xmlName.getXMLName());
    }
    
    /**
     * <p>
     *  This tests the <code>{@link XMLName#setXMLName}</code> method.
     * </p>
     */
    public void testSetXMLName() {
        XMLName xmlName = getXMLName();
        String name = "xmlName";
        xmlName.setXMLName(name);
        assertEquals(name, xmlName.getXMLName());
        
        name = "newName";
        xmlName.setXMLName(name);
        assertEquals(name, xmlName.getXMLName());
    }
    
    /**
     * <p>
     *  This tests the <code>{@link XMLName#getNamespaceURI}</code> method,
     *    in a negative fashion.
     * </p>
     */
    public void testGetNamespaceURI() {
        XMLName xmlName = getXMLName();
        String namespaceURI = "http://www.namespace.com";
        xmlName.setNamespaceURI(namespaceURI);
        assertEquals(namespaceURI, xmlName.getNamespaceURI());
    }
    
    /**
     * <p>
     *  This tests the <code>{@link XMLName#setNamespaceURI}</code> method.
     * </p>
     */
    public void testSetNamespaceURI() {
        XMLName xmlName = getXMLName();
        String namespaceURI = "http://www.namespace.com";
        xmlName.setNamespaceURI(namespaceURI);
        assertEquals(namespaceURI, xmlName.getNamespaceURI());
        
        namespaceURI = "http://www.newNamespace.com";
        xmlName.setNamespaceURI(namespaceURI);
        assertEquals(namespaceURI, xmlName.getNamespaceURI());
    }
}
